﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using System.Drawing;
using System.Text.RegularExpressions;

namespace aFrameEdit
{
    public partial class MainForm
    {
        private int limitParam(int min, int max, int val)
        {
            if (val < min)
            {
                val = min;
            }
            if (val > max)
            {
                val = max;
            }
            return val;
        }

        public int getPowTblIndex(int value)
        {
            int idx = 0;
            int min = 0;
            int mid;
            int max = MixPowTable.Length;

            while (min <= max)
            {
                mid = (min + max) / 2;
                if ((MixPowTable[mid] <= value) && (value < MixPowTable[mid + 1]))
                {
                    idx = mid;
                    break;
                }
                else if (value < MixPowTable[mid])
                {
                    max = mid - 1;
                }
                else
                {
                    min = mid + 1;
                }
            }

            return idx;
        }

        /***** Instrument *****/
        public string getAtdaValue(int idx, int value)
        {
            string retStr;

            switch (idx)
            {
                case 0:
                case 12:
                case 26:
                    retStr = chBalCETxt[value];
                    break;
                case 1:
                case 13:
                    retStr = chHrmTypeTxt[value];
                    break;
                case 9:
                case 21:
                    retStr = chScaleTxt[value];
                    break;
                case 27:
                    retStr = chExtrTypeTxt[value];
                    break;
                case 10:
                case 22:
                case 35:
                    retStr = chSwTxt[value];
                    break;
                case 50:
                case 51:
                case 52:
                case 53:
                case 54:
                case 66:
                    retStr = chPanTxt[value];
                    break;
                case 3:
                case 15:
                case 28:
                case 38:
                case 41:
                case 44:
                case 45:
                    retStr = value.ToString("D");
                    break;
                case 4:
                    retStr = ((Double)value * 0.1).ToString("0.0");
                    break;
                case 16:
                case 29:
                case 30:
                    retStr = value.ToString("D");
                    break;
                case 24:
                case 36:
                case 47:
                    retStr = value.ToString("D");
                    break;
                case 39:
                case 42:
                    Double val = (Double)value * 0.1;
                    if (val > 0) { retStr = "+"; }
                    else { retStr = ""; }
                    retStr += val.ToString("0.0");
                    break;
                case 5:
                case 17:
                    val = (Double)value * 0.01;
                    if (val > 0) { retStr = "+"; }
                    else { retStr = ""; }
                    retStr += val.ToString("0.00");
                    break;
                case 31:
                case 40:
                case 43:
                    val = (Double)value * 0.1;
                    retStr = val.ToString("0.0");
                    break;
                case 6:
                case 7:
                case 8:
                case 18:
                case 19:
                case 20:
                case 25:
                case 32:
                case 33:
                case 34:
                case 37:
                case 46:
                case 48:
                case 55:
                case 56:
                case 57:
                case 58:
                case 59:
                case 60:
                case 61:
                case 62:
                case 63:
                case 64:
                case 65:
                    retStr = value.ToString("D");
                    break;
                case 11:
                case 23:
                    if (value > 0) { retStr = "+"; }
                    else { retStr = ""; }
                    retStr += value.ToString();
                    break;
                case 2:
                case 14:
                    retStr = value.ToString();
                    break;
                case 49:
                    retStr = "A" + value.ToString();
                    break;
                default:
                    retStr = value.ToString();
                    break;
            }
            return retStr;
        }

        public ComboBoxStyle getAtdaComboStyleAndSetItemList(int idx, ref List<string> itemList)
        {
            ComboBoxStyle cbxStyle;

            switch (idx)
            {
                case 1:     // MainOvt
                case 13:    // Sub Ovt
                    cbxStyle = ComboBoxStyle.DropDownList;
                    foreach (string item in chHrmTypeTxt)
                    {
                        itemList.Add(item);
                    }
                    break;
                case 9:     // Main PSC
                case 21:    // Sub PSC
                    cbxStyle = ComboBoxStyle.DropDownList;
                    foreach (string item in chScaleTxt)
                    {
                        itemList.Add(item);
                    }
                    break;
                case 10:    // MainMute
                case 22:    // Sub Mute
                case 35:    // XtraMute
                    cbxStyle = ComboBoxStyle.DropDownList;
                    foreach (string item in chSwTxt)
                    {
                        itemList.Add(item);
                    }
                    break;
                case 27:    // XtraType
                    cbxStyle = ComboBoxStyle.DropDownList;
                    foreach (string item in chExtrTypeTxt)
                    {
                        itemList.Add(item);
                    }
                    break;
                default:
                    cbxStyle = ComboBoxStyle.Simple;
                    break;
            }

            return cbxStyle;
        }

        public int getAtdaValue(int idx, string str, int preVal)
        {
            int j;
            int retVal = preVal;
            string valStr;
            Regex rg = new Regex(@"[^0-9.+-]");

            switch (idx)
            {
                case 0: // Main In
                case 12: // Sub In
                case 26: // Xtra In
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr));
                    }
                    break;
                case 1: // MainOvt
                case 13: // SubOvt
                    for (j = 0; j < 31; j++)
                    {
                        if (chHrmTypeTxt[j] == str)
                        {
                            retVal = j;
                            break;
                        }
                    }
                    break;
                case 3: // MainTune
                case 15: // SubTune
                case 28: // XtraTune
                case 38: // DryC.EqF
                case 41: // DryE.EqF
                case 44: // CentrLPF
                case 45: // Edge HPF
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr));
                    }
                    break;
                case 4: // Main Dcay
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr) * 10);
                    }
                    break;
                case 5: // Main HFD
                case 17: // Sub HFD
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        if (valStr == "0.00")
                        {
                            retVal = 0;
                        }
                        else
                        {
                            if (valStr.StartsWith("+")) // プラス値の場合
                            {
                                retVal = (int)(double.Parse(valStr) * 100);
                            }
                            else if (valStr.StartsWith("-")) // マイナス値の場合
                            {
                                retVal = (int)(double.Parse(valStr) * 100);
                            }
                        }
                    }
                    break;
                case 9: // Main PSC
                case 21: // Sub PSC
                    for (j = 0; j < 8; j++)
                    {
                        if (chScaleTxt[j] == str)
                        {
                            retVal = j;
                            break;
                        }
                    }
                    break;
                case 10: // MainMute
                case 22: // Sub Mute
                case 35: // XtraMute
                    for (j = 0; j < 2; j++)
                    {
                        if (chSwTxt[j] == str)
                        {
                            retVal = j;
                            break;
                        }
                    }
                    break;
                case 11: // Main OD
                case 23: // Sub OD
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        if (valStr == "0")
                        {
                            retVal = 0;
                        }
                        else
                        {
                            if (valStr.StartsWith("+")) // プラス値の場合
                            {
                                retVal = (int)(double.Parse(valStr));
                            }
                            else if (valStr.StartsWith("-")) // マイナス値の場合
                            {
                                retVal = (int)(double.Parse(valStr));
                            }
                        }
                    }
                    break;
                case 16: // Sub Dcay
                case 24: // Sub Delay
                case 29: // Xtra Dcay
                case 30: // Xtra Hold
                case 36: // Xtra Delay
                case 47: // Mute Mask
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr));
                    }
                    break;
                case 27: // Xtra Type
                    for (j = 0; j < 9; j++)
                    {
                        if (chExtrTypeTxt[j] == str)
                        {
                            retVal = j;
                            break;
                        }
                    }
                    break;
                case 31: // XtraFltQ
                case 40: // DryC.EqQ
                case 43: // DryE.EqQ
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr) * 10);
                    }
                    break;
                case 39: // DryC.EqG
                case 42: // DryE.EqG
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        if (valStr == "0.0")
                        {
                            retVal = 0;
                        }
                        else
                        {
                            if (valStr.StartsWith("+")) // プラス値の場合
                            {
                                retVal = (int)(double.Parse(valStr) * 10);
                            }
                            else if (valStr.StartsWith("-")) // マイナス値の場合
                            {
                                retVal = (int)(double.Parse(valStr) * 10);
                            }
                        }
                    }
                    break;
                case 49: // Bend Curve
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr));
                    }
                    break;
                case 50: // Mix Main Pan
                case 51: // Mix Sub  Pan
                case 52: // Mix Xtra Pan
                case 53: // Mix DryC Pan
                case 54: // Mix DryE Pan
                case 66: // MixMasterBal
                    if (str.StartsWith("L"))
                    {
                        valStr = str.Split('L')[1];
                        retVal = (int)(double.Parse(valStr));
                        retVal = limitParam(0, 63, retVal);
                    }
                    else if (str.StartsWith("R"))
                    {
                        valStr = str.Split('R')[1];
                        retVal = (int)(double.Parse(valStr));
                        retVal += 64;
                        retVal = limitParam(65, 127, retVal);
                    }
                    else // C00の場合
                    {
                        retVal = 64;
                    }
                    break;
                default:
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr));
                    }
                    break;
            }
            return retVal;
        }

        /***** Effect *****/
        public string getStrevValue(int idx, int value)
        {
            string retStr;

            switch (idx)
            {
                case 10:
                    retStr = chRevPModeTxt[value];
                    break;
                case 14:
                    retStr = chSwTxt[value];
                    break;
                case 0:
                    retStr = ((Double)value * 0.1).ToString("0.0");
                    break;
                case 1:
                    retStr = value.ToString();
                    break;
                case 12:
                case 13:
                    retStr = value.ToString();
                    break;
                case 2:
                case 3:
                case 5:
                case 6:
                case 7:
                case 8:
                case 9:
                case 11:
                    retStr = value.ToString();
                    break;
                case 4:
                    retStr = ((Double)value * 0.01).ToString("0.00");
                    break;
                default:
                    retStr = value.ToString();
                    break;
            }
            return retStr;
        }

        public string getStdelayValue(int idx, int value)
        {
            string retStr;

            switch (idx)
            {
                case 0:
                    retStr = chDlyTypeTxt[value];
                    break;
                case 11:
                    retStr = chDlyPModeTxt[value];
                    break;
                case 15:
                    retStr = chSwTxt[value];
                    break;
                case 1:
                case 2:
                    retStr = ((Double)value * 0.1).ToString("0.0");
                    break;
                case 3:
                case 5:
                case 6:
                case 7:
                case 9:
                case 12:
                    retStr = value.ToString();
                    break;
                case 4:
                    retStr = ((Double)value * 0.01).ToString("0.00");
                    break;
                case 8:
                    retStr = ((Double)value * 0.1).ToString("0.0");
                    break;
                case 10:
                    retStr = value.ToString();
                    break;
                case 13:
                case 14:
                    retStr = value.ToString();
                    break;
                default:
                    retStr = value.ToString();
                    break;
            }
            return retStr;
        }

        public string getStchorusValue(int idx, int value)
        {
            string retStr;

            switch (idx)
            {
                case 0:
                    retStr = chChoTypeTxt[value];
                    break;
                case 8:
                    retStr = chSwTxt[value];
                    break;
                case 1:
                    retStr = ((Double)value * 0.1).ToString("0.0");
                    break;
                case 2:
                case 3:
                case 6:
                case 7:
                    retStr = value.ToString();
                    break;
                case 4:
                case 5:
                    retStr = value.ToString();
                    break;
                default:
                    retStr = value.ToString();
                    break;
            }
            return retStr;
        }

        public string getStflangerValue(int idx, int value)
        {
            string retStr;

            switch (idx)
            {
                case 6:
                    retStr = chFlgPModeTxt[value];
                    break;
                case 10:
                    retStr = chSwTxt[value];
                    break;
                case 0:
                case 1:
                case 2:
                case 3:
                case 4:
                case 5:
                case 7:
                    retStr = value.ToString();
                    break;
                case 8:
                case 9:
                    retStr = value.ToString();
                    break;
                default:
                    retStr = value.ToString();
                    break;
            }
            return retStr;
        }

        public string getStphaserValue(int idx, int value)
        {
            string retStr;

            switch (idx)
            {
                case 7:
                    retStr = chPhsPModeTxt[value];
                    break;
                case 11:
                    retStr = chSwTxt[value];
                    break;
                case 0:
                case 1:
                case 2:
                case 3:
                case 4:
                case 5:
                case 8:
                    retStr = value.ToString();
                    break;
                case 6:
                    retStr = value.ToString();
                    break;
                case 9:
                case 10:
                    retStr = value.ToString();
                    break;
                default:
                    retStr = value.ToString();
                    break;
            }
            return retStr;
        }

        public string getStwahValue(int idx, int value)
        {
            string retStr;

            switch (idx)
            {
                case 0:
                    retStr = chWahTypeTxt[value];
                    break;
                case 5:
                case 9:
                    retStr = chSwTxt[value];
                    break;
                case 1:
                case 6:
                    retStr = value.ToString();
                    break;
                case 2:
                case 3:
                    retStr = value.ToString();
                    break;
                case 4:
                    retStr = ((Double)value * 0.1).ToString("0.0");
                    break;
                case 7:
                case 8:
                    retStr = value.ToString();
                    break;
                default:
                    retStr = value.ToString();
                    break;
            }
            return retStr;
        }

        public ComboBoxStyle getRevComboStyleAndSetItemList(int idx, ref List<string> itemList)
        {
            ComboBoxStyle cbxStyle;

            switch (idx)
            {
                case 10: // PressMode
                    cbxStyle = ComboBoxStyle.DropDownList;
                    foreach (string item in chRevPModeTxt)
                    {
                        itemList.Add(item);
                    }
                    break;
                case 14: // Reverb Sw
                    cbxStyle = ComboBoxStyle.DropDownList;
                    foreach (string item in chSwTxt)
                    {
                        itemList.Add(item);
                    }
                    break;
                default:
                    cbxStyle = ComboBoxStyle.Simple;
                    break;
            }

            return cbxStyle;
        }

        public ComboBoxStyle getDelayComboStyleAndSetItemList(int idx, ref List<string> itemList)
        {
            ComboBoxStyle cbxStyle;

            switch (idx)
            {
                case 0:  // Type
                    cbxStyle = ComboBoxStyle.DropDownList;
                    foreach (string item in chDlyTypeTxt)
                    {
                        itemList.Add(item);
                    }
                    break;
                case 11: // PressMode
                    cbxStyle = ComboBoxStyle.DropDownList;
                    foreach (string item in chDlyPModeTxt)
                    {
                        itemList.Add(item);
                    }
                    break;
                case 15: // Delay Sw
                    cbxStyle = ComboBoxStyle.DropDownList;
                    foreach (string item in chSwTxt)
                    {
                        itemList.Add(item);
                    }
                    break;
                default:
                    cbxStyle = ComboBoxStyle.Simple;
                    break;
            }

            return cbxStyle;
        }

        public ComboBoxStyle getChorusComboStyleAndSetItemList(int idx, ref List<string> itemList)
        {
            ComboBoxStyle cbxStyle;

            switch (idx)
            {
                case 0: // Type
                    cbxStyle = ComboBoxStyle.DropDownList;
                    foreach (string item in chChoTypeTxt)
                    {
                        itemList.Add(item);
                    }
                    break;
                case 8: // Chorus Sw
                    cbxStyle = ComboBoxStyle.DropDownList;
                    foreach (string item in chSwTxt)
                    {
                        itemList.Add(item);
                    }
                    break;
                default:
                    cbxStyle = ComboBoxStyle.Simple;
                    break;
            }
            return cbxStyle;
        }

        public ComboBoxStyle getFlangerComboStyleAndSetItemList(int idx, ref List<string> itemList)
        {
            ComboBoxStyle cbxStyle;

            switch (idx)
            {
                case 6:  // PressMode
                    cbxStyle = ComboBoxStyle.DropDownList;
                    foreach (string item in chFlgPModeTxt)
                    {
                        itemList.Add(item);
                    }
                    break;
                case 10: // Flnager Sw
                    cbxStyle = ComboBoxStyle.DropDownList;
                    foreach (string item in chSwTxt)
                    {
                        itemList.Add(item);
                    }
                    break;
                default:
                    cbxStyle = ComboBoxStyle.Simple;
                    break;
            }
            return cbxStyle;
        }

        public ComboBoxStyle getPhaserComboStyleAndSetItemList(int idx, ref List<string> itemList)
        {
            ComboBoxStyle cbxStyle;

            switch (idx)
            {
                case 7:  // PressMode
                    cbxStyle = ComboBoxStyle.DropDownList;
                    foreach (string item in chPhsPModeTxt)
                    {
                        itemList.Add(item);
                    }
                    break;
                case 11: // Phaser Sw
                    cbxStyle = ComboBoxStyle.DropDownList;
                    foreach (string item in chSwTxt)
                    {
                        itemList.Add(item);
                    }
                    break;
                default:
                    cbxStyle = ComboBoxStyle.Simple;
                    break;
            }
            return cbxStyle;
        }

        public ComboBoxStyle getWahComboStyleAndSetItemList(int idx, ref List<string> itemList)
        {
            ComboBoxStyle cbxStyle;

            switch (idx)
            {
                case 0: // Type
                    cbxStyle = ComboBoxStyle.DropDownList;
                    foreach (string item in chWahTypeTxt)
                    {
                        itemList.Add(item);
                    }
                    break;
                case 5: // PressSw
                    cbxStyle = ComboBoxStyle.DropDownList;
                    foreach (string item in chSwTxt)
                    {
                        itemList.Add(item);
                    }
                    break;
                case 9: // Wah Sw
                    cbxStyle = ComboBoxStyle.DropDownList;
                    foreach (string item in chSwTxt)
                    {
                        itemList.Add(item);
                    }
                    break;
                default:
                    cbxStyle = ComboBoxStyle.Simple;
                    break;
            }
            return cbxStyle;
        }

        public int getStrevValue(int idx, string str, int preVal)
        {
            int j;
            int retVal = preVal;
            string valStr;
            Regex rg = new Regex(@"[^0-9.+-]");

            switch (idx)
            {
                case 0: // Time
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr) * 10);
                    }
                    break;
                case 1:  // Pre Delay
                case 12: // PressAtck
                case 13: // PressRele
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr));
                    }
                    break;
                case 4: // HF Damp
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr) * 100);
                    }
                    break;
                case 10: // PressMode
                    for (j = 0; j < 5; j++)
                    {
                        if (chRevPModeTxt[j] == str)
                        {
                            retVal = j;
                            break;
                        }
                    }
                    break;
                case 14: // Reverb Sw
                    for (j = 0; j < 2; j++)
                    {
                        if (chSwTxt[j] == str)
                        {
                            retVal = j;
                            break;
                        }
                    }
                    break;
                default:
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr));
                    }
                    break;
            }
            return retVal;
        }

        public int getStdelayValue(int idx, string str, int preVal)
        {
            int j;
            int retVal = preVal;
            string valStr;
            Regex rg = new Regex(@"[^0-9.+-]");

            switch (idx)
            {
                case 0: // Type
                    for (j = 0; j < 4; j++)
                    {
                        if (chDlyTypeTxt[j] == str)
                        {
                            retVal = j;
                            break;
                        }
                    }
                    break;
                case 1: // Time L
                case 2: // Time R
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr) * 10);
                    }
                    break;
                case 4: // HF Damp
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr) * 100);
                    }
                    break;
                case 8: // Mod Rate
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr) * 10);
                    }
                    break;
                case 10: // Mode Phase
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = int.Parse(valStr);
                    }
                    break;
                case 11: // Press Mode
                    for (j = 0; j < 7; j++)
                    {
                        if (chDlyPModeTxt[j] == str)
                        {
                            retVal = j;
                            break;
                        }
                    }
                    break;
                case 13: // PressAtck
                case 14: // PressRele
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr));
                    }
                    break;
                case 15: // Delay Sw
                    for (j = 0; j < 2; j++)
                    {
                        if (chSwTxt[j] == str)
                        {
                            retVal = j;
                            break;
                        }
                    }
                    break;
                default:
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr));
                    }
                    break;
            }
            return retVal;
        }

        public int getStchrousValue(int idx, string str, int preVal)
        {
            int j;
            int retVal = preVal;
            string valStr;
            Regex rg = new Regex(@"[^0-9.+-]");

            switch (idx)
            {
                case 0: // Type
                    for (j = 0; j < 6; j++)
                    {
                        if (chChoTypeTxt[j] == str)
                        {
                            retVal = j;
                            break;
                        }
                    }
                    break;
                case 1: // Mod Rate
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr) * 10);
                    }
                    break;
                case 3: // Mod Phase
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr));
                    }
                    break;
                case 4: // Wet HPF
                case 5: // Wet LPF
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr));
                    }
                    break;
                case 8: // Chorus Sw
                    for (j = 0; j < 2; j++)
                    {
                        if (chSwTxt[j] == str)
                        {
                            retVal = j;
                            break;
                        }
                    }
                    break;
                default:
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr));
                    }
                    break;
            }
            return retVal;
        }

        public int getStflangerValue(int idx, string str, int preVal)
        {
            int j;
            int retVal = preVal;
            string valStr;
            Regex rg = new Regex(@"[^0-9.+-]");

            switch (idx)
            {
                case 3: // RESO
                case 4: // XFB
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        if (valStr == "0")
                        {
                            retVal = 0;
                        }
                        else
                        {
                            if (valStr.StartsWith("+")) // プラス値の場合
                            {
                                retVal = (int)(double.Parse(valStr));
                            }
                            else if (valStr.StartsWith("-")) // マイナス値の場合
                            {
                                retVal = (int)(double.Parse(valStr));
                            }
                        }
                    }
                    break;
                case 5: // MOD PH
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr));
                    }
                    break;
                case 6: // Press Mode
                    for (j = 0; j < 6; j++)
                    {
                        if (chFlgPModeTxt[j] == str)
                        {
                            retVal = j;
                            break;
                        }
                    }
                    break;
                case 8:  // PressAtck
                case 9:  // PressRele
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr));
                    }
                    break;
                case 10: // Flanger Sw
                    for (j = 0; j < 2; j++)
                    {
                        if (chSwTxt[j] == str)
                        {
                            retVal = j;
                            break;
                        }
                    }
                    break;
                default:
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr));
                    }
                    break;
            }
            return retVal;
        }

        public int getStphaserValue(int idx, string str, int preVal)
        {
            int j;
            int retVal = preVal;
            string valStr;
            Regex rg = new Regex(@"[^0-9.+-]");

            switch (idx)
            {
                case 3: // RESO
                case 4: // XFB
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        if (valStr == "0")
                        {
                            retVal = 0;
                        }
                        else
                        {
                            if (valStr.StartsWith("+")) // プラス値の場合
                            {
                                retVal = (int)(double.Parse(valStr));
                            }
                            else if (valStr.StartsWith("-")) // マイナス値の場合
                            {
                                retVal = (int)(double.Parse(valStr));
                            }
                        }
                    }
                    break;
                case 5: // MOD PH
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr));
                    }
                    break;
                case 7: // Press Mode
                    for (j = 0; j < 6; j++)
                    {
                        if (chPhsPModeTxt[j] == str)
                        {
                            retVal = j;
                            break;
                        }
                    }
                    break;
                case 9:  // PressAtck
                case 10: // PressRele
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr));
                    }
                    break;
                case 11: // Phase Sw
                    for (j = 0; j < 2; j++)
                    {
                        if (chSwTxt[j] == str)
                        {
                            retVal = j;
                            break;
                        }
                    }
                    break;
                default:
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr));
                    }
                    break;
            }
            return retVal;
        }

        public int getStwahValue(int idx, string str, int preVal)
        {
            int j;
            int retVal = preVal;
            string valStr;
            Regex rg = new Regex(@"[^0-9.+-]");

            switch (idx)
            {
                case 0: // Type
                    for (j = 0; j < 5; j++)
                    {
                        if (chWahTypeTxt[j] == str)
                        {
                            retVal = j;
                            break;
                        }
                    }
                    break;
                case 2: // Freq Min
                case 3: // Freq Max
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr));
                    }
                    break;
                case 4: // Filter Q
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr) * 10);
                    }
                    break;
                case 5: // Press Sw
                    for (j = 0; j < 2; j++)
                    {
                        if (chSwTxt[j] == str)
                        {
                            retVal = j;
                            break;
                        }
                    }
                    break;
                case 7:  // PressAtck
                case 8: // PressRele
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(valStr));
                    }
                    break;
                case 9: // Wah Sw
                    for (j = 0; j < 2; j++)
                    {
                        if (chSwTxt[j] == str)
                        {
                            retVal = j;
                            break;
                        }
                    }
                    break;
                default:
                    valStr = rg.Replace(str, "");
                    if (valStr != "")
                    {
                        retVal = (int)(double.Parse(str));
                    }
                    break;
            }
            return retVal;
        }

        /***** Group *****/

        public void setGrpAndNumWithBankName(string bankName)
        {
            switch (bankName)
            {
                case "B":
                    if (button_FNC.BackColor == Color.Gold)
                    {
                        currentToneInfo.mGrp = 5;
                    }
                    else
                    {
                        currentToneInfo.mGrp = 1;
                    }
                    break;
                case "C":
                    if (button_FNC.BackColor == Color.Gold)
                    {
                        currentToneInfo.mGrp = 6;
                    }
                    else
                    {
                        currentToneInfo.mGrp = 2;
                    }
                    break;
                case "D":
                    if (button_FNC.BackColor == Color.Gold)
                    {
                        currentToneInfo.mGrp = 7;
                    }
                    else
                    {
                        currentToneInfo.mGrp = 3;
                    }
                    break;
                case "A":
                default:
                    if (button_FNC.BackColor == Color.Gold)
                    {
                        currentToneInfo.mGrp = 4;
                    }
                    else
                    {
                        currentToneInfo.mGrp = 0;
                    }
                    break;
            }
            currentToneInfo.mNum = 0;
        }

    }
}
